<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AdvancedConfigDialog</name>
    <message>
        <source>Advanced Settings</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <source>Crop Image When Loaded</source>
        <translation>Bild nach dem Laden beschneiden</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>OCR Settings</source>
        <translation>OCR Einstellungen</translation>
    </message>
    <message>
        <source>OCR Engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuneiform</source>
        <translation></translation>
    </message>
    <message>
        <source>tesseract</source>
        <translation></translation>
    </message>
    <message>
        <source>Tesseract Setup</source>
        <translation>Tesseract Einstellungen</translation>
    </message>
    <message>
        <source>Location of the  tessdata directory:</source>
        <translation>Ort des tessdata Verzeichnisses:</translation>
    </message>
</context>
<context>
    <name>MainForm</name>
    <message>
        <source>Recognition language</source>
        <translation>Erkennungs-Sprache</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</source>
        <translation>Bilddateien  (*.png *.jpg *.jpeg *.bmp *.tiff *.tif *.gif *.pnm *.pgm *.pbm *.ppm)</translation>
    </message>
    <message>
        <source>There is an unsaved text in the editor window. Do you want to save it?</source>
        <translation>Nicht gespeicherter Text im Bearbeitungsfenster. Jetzt speichern?</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Starting cuneiform failed</source>
        <translation>Der Start von &quot;Cuneiform&quot; schlug fehl</translation>
    </message>
    <message>
        <source>The system said: </source>
        <translation>Das System sagt:</translation>
    </message>
    <message>
        <source>program not found</source>
        <translation>Programm nicht gefunden</translation>
    </message>
    <message>
        <source>No image loaded</source>
        <translation>Kein Bild geöffnet</translation>
    </message>
    <message>
        <source>About YAGF</source>
        <translation>Über YAGF</translation>
    </message>
    <message>
        <source>http://symmetrica.net/cuneiform-linux/yagf-en.html</source>
        <translation>http://symmetrica.net/cuneiform-linux/yagf-en.html</translation>
    </message>
    <message>
        <source>Recognizing pages...</source>
        <translation>Erkenne Seiten...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation>Bild speichern</translation>
    </message>
    <message>
        <source>Importing pages from the PDF document...</source>
        <translation>Seiten aus dem PDF Dokument importieren...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>No compatible PDF converter software could be found. Please install either the pdftoppm utility or the GhostScript package (from this the gs command will be required).</source>
        <translation>Es konnte keine kompatible PDF Konvertierungssoftware gefunden werden. Bitte installieren Sie entweder pdftoppm aus dem Paket poppler oder das GhostScript Paket (aus diese wird der &quot;gs&quot; Befehl gebraucht).</translation>
    </message>
    <message>
        <source>PDF file name may not be empty</source>
        <translation>PDF Dateiname darf nicht leer sein</translation>
    </message>
    <message>
        <source>Select an existing directory for output or create some new one</source>
        <translation>Wählen Sie ein bestehendes Verzeichnis für die Ausgabe oder erstellen sie ein neues</translation>
    </message>
    <message>
        <source>Selecting Directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
    <message>
        <source>The selected directory is not empty</source>
        <translation>Das ausgewählte Verzeichnis ist nicht leer</translation>
    </message>
    <message>
        <source>Starting tesseract failed</source>
        <translation>tesseract startete nicht</translation>
    </message>
    <message>
        <source>cuneiform not found, switching to tesseract</source>
        <translation>cuneiform nicht gefunden, wechsle zu tesseract</translation>
    </message>
    <message>
        <source>No recognition engine found.
Please install either cuneiform or tesseract</source>
        <translation>Keine Erkennungs Engine gefunden.
Bitte cuneiform und/oder tesseract installieren</translation>
    </message>
    <message>
        <source>tesseract not found, switching to cuneiform</source>
        <translation>tesseract nicht gefunden, wechsel zu cuneiform</translation>
    </message>
    <message>
        <source>No PDF converter installed</source>
        <translation>Kein PDF Konvertierer installiert</translation>
    </message>
    <message utf8="true">
        <source>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Andrei Borovsky&lt;/p&gt; This is a free software distributed under GPL v3. Visit &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; for more details.</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end (Noch ein weiteres grafisches Frontend) fürr cuneiform und tesseract OCR (Optical Character Recognition = Optische Zeichen Erkennung) engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Andrei Borovsky&lt;/p&gt; Dies ist freie Softwater die unter der GPL v3 verbreitet wird. Besuchen Sie &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; für weitere Informationen. {2009-2012?}</translation>
    </message>
    <message>
        <source>Using Cuneiform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using Tesseract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scanning is impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No scanning front-end is found. Please install XSane in order to perform scanning.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to detect text areas on this page.
The page possibly lacks contrast. Try to select blocks manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected directoy is not empty. Please select or create another one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load project.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation>Hauptfenster</translation>
    </message>
    <message>
        <source>Larger view</source>
        <translation>Ansicht vergrößern</translation>
    </message>
    <message>
        <source>Smaller view</source>
        <translation>Ansicht verkleinern</translation>
    </message>
    <message>
        <source>Rotate 90 CCW</source>
        <translation>Um 90° gegen den UZS drehen</translation>
    </message>
    <message>
        <source>Rotate 180</source>
        <translation>Um 180° drehen</translation>
    </message>
    <message>
        <source>Rotate 90 CW</source>
        <translation>Um 90° im UZS drehen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation>Werkzeugleiste</translation>
    </message>
    <message>
        <source>S&amp;can...</source>
        <translation>Bild ei&amp;nlesen...</translation>
    </message>
    <message>
        <source>Scanning images using XSane...</source>
        <translation>Bilder mit «XSane» einlesen...</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Save text...</source>
        <translation>Text &amp;speichern...</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;Open Image...</source>
        <translation>Bild &amp;öffnen...</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Recognize</source>
        <translation>Texte&amp;rkennung: aktuelle Seite</translation>
    </message>
    <message>
        <source>Recognizing text...</source>
        <translation>Texterkennung...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Choose &amp;Language</source>
        <translation>&amp;Wählen Sie eine Sprache</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>B&amp;eenden</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>Vorherige Seite</translation>
    </message>
    <message>
        <source>Move to previous image</source>
        <translation>Zum vorherigen Bild wechseln</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <source>Move to next image</source>
        <translation>Zum nächsten Bild wechseln</translation>
    </message>
    <message>
        <source>Online Help</source>
        <translation>Online-&amp;Hilfe</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>Ü&amp;ber...</translation>
    </message>
    <message>
        <source>Copy To Clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Copy recognized text to clipboard</source>
        <translation>Text in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Recognize &amp;All Pages</source>
        <translation>Texterkennung: &amp;alle Seiten</translation>
    </message>
    <message>
        <source>Recognize All Pages</source>
        <translation>Texterkennung: alle Seiten</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Clear all blocks</source>
        <translation>Alle Markierungen entfernen</translation>
    </message>
    <message>
        <source>Delete the current block</source>
        <translation>Aktuelle Markierung entfernen</translation>
    </message>
    <message>
        <source>Recognize block</source>
        <translation>Texterkennung: aktuelle Markierung</translation>
    </message>
    <message>
        <source>Recognize this block</source>
        <translation>Diese Markierung erkennen</translation>
    </message>
    <message>
        <source>Clear numbers</source>
        <translation>Nummern löschen</translation>
    </message>
    <message>
        <source>Crear block numbering</source>
        <translation>Markierungsnummerierung löschen</translation>
    </message>
    <message>
        <source>Check spelling</source>
        <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
        <source>Save current image...</source>
        <translation>Aktuelles Bild speichern...</translation>
    </message>
    <message>
        <source>Save currently opened image in its real size</source>
        <translation>Aktuelles Bild mit wirklicher Auflösung speichern</translation>
    </message>
    <message>
        <source>Save block</source>
        <translation>Block speichern</translation>
    </message>
    <message>
        <source>Save the current block to the image file</source>
        <translation>Aktuellen Block in die Bilddatei speichern</translation>
    </message>
    <message>
        <source>Select HTML format</source>
        <translation>HTML Format auswählen</translation>
    </message>
    <message>
        <source>Select HTML format as recognition output</source>
        <translation>HTML Format als Ausgabe der Erkennung wählen</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Ein&amp;stellungen</translation>
    </message>
    <message>
        <source>&lt;&lt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Hide/Show Toolbar</source>
        <translation>Werkzeugleiste anzeigen/verbergen</translation>
    </message>
    <message>
        <source>Import from PDF...</source>
        <translation>Aus PDF importieren ...</translation>
    </message>
    <message>
        <source>Import pages from PDF documents</source>
        <translation>Seiten aus PDF Dokumenten importieren</translation>
    </message>
    <message>
        <source>OCR Settings</source>
        <translation>OCR Einstellungen</translation>
    </message>
    <message>
        <source>Set up the OCR parameters</source>
        <translation>OCR Parameter einstellen</translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation>Bild einfügen</translation>
    </message>
    <message>
        <source>Paste image from clipboard</source>
        <translation>Bild der Zwischenablage einfügen</translation>
    </message>
    <message>
        <source>Select Text Area</source>
        <translation>Textbereich auwählen</translation>
    </message>
    <message>
        <source>Deskew  Block</source>
        <translation>Block entzerren</translation>
    </message>
    <message>
        <source>Deskew the current block</source>
        <translation>Aktuellen Block entzerren</translation>
    </message>
    <message>
        <source>Deskew</source>
        <translation>Entzerren</translation>
    </message>
    <message>
        <source>Correct the page skew </source>
        <translation>Seitenverzerrung korrigieren</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Erweiterte Einstellungen</translation>
    </message>
    <message>
        <source>The settings you should probably never change</source>
        <translation>Einstellungen die sie wahrscheinlich nie ändern sollten</translation>
    </message>
    <message>
        <source>select multiple blocks</source>
        <translation>Mehrere Blöcke auswählen</translation>
    </message>
    <message>
        <source>Splits text into several blocks</source>
        <translation>Teilt Text in mehrere Blöcke</translation>
    </message>
    <message>
        <source>Toggle Large/Small Icons</source>
        <translation>Große/kleine Icons</translation>
    </message>
    <message>
        <source>toolBar_2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Recognition Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepare Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Project...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepare the page for recognition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PopplerDialog</name>
    <message>
        <source>Import from PDF</source>
        <translation>Aus PDF importieren</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Auswählen...</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Seiten</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Von</translation>
    </message>
    <message>
        <source>To</source>
        <translation>bis</translation>
    </message>
    <message>
        <source>Entire Document</source>
        <translation>Ganzes Dokument</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>JPEG Files (*.jpg)</source>
        <translation>JPEG Dateien (*.jpg)</translation>
    </message>
    <message>
        <source>PNG Files (*.png)</source>
        <translation>PNG Dateien (*.png)</translation>
    </message>
    <message>
        <source>Failed to save the image</source>
        <translation>Speichern des Bilds schlug fehl</translation>
    </message>
    <message>
        <source>Required spelling dictionary (%1) is not found.
Spell-checking is disabled.
Try to install an appropriate aspell dictionary.</source>
        <translation>Erforderliches (%1) Wörterbuch nicht gefunden.
Rechtschreibprüfung ist deaktiviert.
Bitte entsprechendes aspell Wörterbuch installieren.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Warnung</translation>
    </message>
    <message>
        <source>Select Project Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Danish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hungarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latvian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lithuanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Romanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian-English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serbian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slovenian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German Gothic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Norwegian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish Gothic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turkish</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Drop files here</source>
        <translation>Dateien hier ablegen</translation>
    </message>
</context>
</TS>
